# pytest-lobster

This is a [pytest](http://pytest.org) plugin that writes test information into a
[lobster](https://github.com/bmw-software-engineering/lobster) json file.

When tests are run with pytest (later than 7.0), e.g., allowing
to simple stash information into the common data types, a BMW-Lobster
requirement tracking tool report is created showing what tests have been
run and are connected to what requirements.

---
[![status-badge](https://ci.codeberg.org/api/badges/14963/status.svg)](https://ci.codeberg.org/repos/14963)
